/*
This sketch connects the IRW Board with processing.
The interface receives the temperature reading from the connected sensors
through the serial port and represents it according to whether it is the 
typical human body temperature. Green circles appear on each sensor until
the sensor detects the set temperature for a person and turns red.
 */
 
import processing.serial.*; //Import of the processing library to perform serial communication
//Variables definition
Serial myPort;  // Create object from Serial class
float[] val=new float[11];      // Array of datas received from the serial port
PImage logo; //I define an image variable that I will use to insert the IRW logo in my interface
PFont font; //I define a font variable which I will use to insert texts into my interface
float angle; //I define a decimal type variable that I will use to give the angle of rotation data 
//that I want to rotate my objects

void setup() //This function is executed only once when starting the script (at the beginning of the 
//application) and is used to give the initial value to the defined variables
{
  size(1000, 1000);  //Configure the size of the window  
  println("Ports detected: ");  //Print text
  printArray(Serial.list());  //Print ports detected
  String portName = Serial.list()[1];// Set the port name
  myPort = new Serial(this, portName, 9600); //Configure the serial communication.
  //The baud (9600) must be the same in the microcontroller 
  myPort.bufferUntil('\n'); //Set the reading end point of each shipment through the serial port  
 logo=loadImage("IRWlogo.png"); //Initializes a PImage passing an image file name  
 font=loadFont("Arial-Black-48.vlw"); //Initializes a PFont passing an font file name
 textFont(font,20); //Define the font size
 angle=0;//initial rotation angle of the circles
}

void draw() //This function is executed on loop and draw in the interface the objets configurated 
{
  //////////Set the background image that not change
  /////Background color
  background(200,191,231);  // Set background to blue clear on RGB format
  pushMatrix();  //Save the current matrix (translate, rotate and scale values)
  imageMode(CENTER); //Draw image using CENTER mode 
  translate(500,500);  //Move the anchor point to a certain position. After this the (0,0) is the certain position.
  rotate(angle);  //Change plane rotation according the axis
  
  for(int i=0;i<11;i++){ //These are codeblock that cycle through a condition, i=sersors number, 
  //I use i to define the each sensor draw 
  if(val[i]<28.0 || val[i]>37.0){ //If the temperature value is betwen those values, 
  //then the human presence is not detected and the circle is green
    fill(34,177,76);//Sets the color used to fill shapes (green) 
  }else{ //If the temperature value is not betwen those values, then the human presence is detected 
  //and the circle is red
    fill(237,28,36);//Sets the color used to fill shapes (red)
  }
    
  noStroke(); //remove contour line from drawn shapes
  circle(0, -400, 180);  // Draw a circle to each sensor (posX,posY,Diameter)
  fill(0);//Sets the color used to fill texts (black)
  textAlign(CENTER); //Justify the text to the center

  text("IR Sensor ",0,-400);  //Displays a text on the screen (string,posX,posY)
  text(i+1,70,-400);  //Displays a text on the screen (string,posX,posY), Indicates the sensor number
  text(val[i],0,-350);  //Displays a text on the screen (string,posX,posY), Indicates the sensor temperature value 
  rotate(2*PI/11); //rotate the drawing plane according to the angle calculated by dividing 
  //the degrees of the circle = 2PI by i (number of sensors)
  
}
popMatrix();  //Go back to the last saved matrix
image(logo,500,500,300,300);  //Draw the logo. imageMode(CENTER) --> (img,posx,posy,width,height)
angle+=0.002; //increase the value of the variable angle a fixed value (+0.02)
}

void serialEvent(Serial myPort){  //This function runs when it receives data through the serial port
  String inString = myPort.readStringUntil('\n'); //Saves the received data in the variable instring until 
  //it reads the end of the carriage (/ n)
  if(inString!=null){ //Saves the received data in the variable instring until it reads the end of the carriage (/n)
    inString=trim(inString); //Removes whitespace characters 
    float[] values=float(split(inString,";")); // Split breaks the string where it finds the character;
//Float converts chunks to decimal type
//Save the data in the array values
    for(int i=0;i<values.length;i++){
     val[i]=values[i]; ////Save the data in the array val
     println(val);
    }
  }
}
